@@ -6,6 +6,7 @@ from citrination_client.data.ingest import IngestClient
 
 from pypif import pif
 
+import json
 import os
 import shutil
 import requests
@@ -30,6 +31,7 @@ class DataClient(BaseClient):
         members = [
             "upload",
             "upload_with_ingester",
+            "upload_with_template_csv_ingester",
             "list_ingesters",
             "list_files",
             "matched_file_count",
@@ -40,6 +42,7 @@ class DataClient(BaseClient):
             "create_dataset_version",
             "get_ingest_status",
             "get_pif",
+            "get_pif_with_metadata",
             "update_dataset",
             "delete_dataset",
             "get_data_view_ids"
@@ -58,7 +61,7 @@ class DataClient(BaseClient):
 
         :param dataset_id: The ID of the dataset to search for files.
         :type dataset_id: Union[int, str]
-        :param source_path: The path to the file on the source host asdf
+        :param source_path: The path to the file on the source host
         :type source_path: str
         :param dest_path: The path to the file where the contents of the upload will be written (on the dest host)
         :type dest_path: str
@@ -155,7 +158,7 @@ class DataClient(BaseClient):
 
         :param dataset_id: The ID of the dataset to search for files.
         :type dataset_id: Union[int, str]
-        :param source_path: The path to the file on the source host asdf
+        :param source_path: The path to the file on the source host
         :type source_path: str
         :param ingester: The ingester being used
         :type ingester: class:`citrination_client.data.ingest.Ingester`
@@ -186,7 +189,7 @@ class DataClient(BaseClient):
 
         :param dataset_id: The ID of the dataset to search for files.
         :type dataset_id: Union[int, str]
-        :param source_path: The path to the file on the source host asdf
+        :param source_path: The path to the file on the source host
         :type source_path: str
         :param dest_path: The path to the file where the contents of the upload will be written (on the dest host)
         :type dest_path: str
@@ -354,7 +357,7 @@ class DataClient(BaseClient):
             with open(local_path, 'wb') as output_file:
                 shutil.copyfileobj(r.raw, output_file)
 
-    def get_pif(self, dataset_id, uid, dataset_version = None):
+    def get_pif(self, dataset_id, uid, dataset_version = None, pif_version = None):
         """
         Retrieves a PIF from a given dataset.
 
@@ -362,19 +365,62 @@ class DataClient(BaseClient):
         :type dataset_id: int
         :param uid: The uid of the PIF to retrieve
         :type uid: str
-        :param dataset_version: The dataset version to look for the PIF in. If nothing is supplied, the latest dataset version will be searched
+        :param dataset_version: The dataset version to look for the PIF in.
+            If nothing is supplied, the latest dataset version will be searched.
         :type dataset_version: int
+        :param pif_version: The version of the PIF to look for. If nothing is
+            supplied, the current PIF version will be returned.
+        :type pif_version: int
         :return: A :class:`Pif` object
         :rtype: :class:`Pif`
         """
         failure_message = "An error occurred retrieving PIF {}".format(uid)
-        if dataset_version == None:
-            response = self._get(routes.pif_dataset_uid(dataset_id, uid), failure_message=failure_message)
-        else:
-            response = self._get(routes.pif_dataset_version_uid(dataset_id, dataset_version, uid), failure_message=failure_message)
+        path = _get_pif_path(
+            dataset_id,
+            uid,
+            dataset_version = dataset_version,
+            pif_version = pif_version
+        )
+        response = self._get(path, failure_message=failure_message)
 
         return pif.loads(response.content.decode("utf-8"))
 
+    def get_pif_with_metadata(self, dataset_id, uid, dataset_version = None, pif_version = None):
+        """
+        Retrieves a PIF from a given dataset, along with information regarding
+        the dataset it belongs to, its version number, and when it was last
+        updated.
+
+        :param dataset_id: The id of the dataset to retrieve PIF from
+        :type dataset_id: int
+        :param uid: The uid of the PIF to retrieve
+        :type uid: str
+        :param dataset_version: The dataset version to look for the PIF in.
+            If nothing is supplied, the latest dataset version will be searched.
+        :type dataset_version: int
+        :param pif_version: The version of the PIF to look for. If nothing is
+            supplied, the current PIF version will be returned.
+        :type pif_version: int
+        :return: A dict with two keys - ``pif`` (:class:`Pif`) and ``metadata`` (dict)
+        :rtype: dict
+        """
+        failure_message = "An error occurred retrieving PIF {}".format(uid)
+        path = _get_pif_path(
+            dataset_id,
+            uid,
+            dataset_version = dataset_version,
+            pif_version = pif_version,
+            with_metadata = True
+        )
+        response = self._get_success_json(
+            self._get(path, failure_message=failure_message)
+        )['data']
+
+        return {
+            'metadata': response['metadata'],
+            'pif': pif.loads(json.dumps(response['pif']))
+        }
+
     def create_dataset(self, name=None, description=None, public=False):
         """
         Create a new data set.
@@ -492,3 +538,20 @@ def _get_s3_presigned_url(response_dict):
     """
     url = response_dict['url']
     return url['scheme']+'://'+url['host']+url['path']+'?'+url['query']
+
+def _get_pif_path(dataset_id, uid, dataset_version = None, pif_version = None, with_metadata = False):
+    if dataset_version == None:
+        return routes.pif_dataset_uid(
+            dataset_id,
+            uid,
+            pif_version = pif_version,
+            with_metadata = with_metadata
+        )
+    else:
+        return routes.pif_dataset_version_uid(
+            dataset_id,
+            dataset_version,
+            uid,
+            pif_version = pif_version,
+            with_metadata = with_metadata
+        )
