@@ -28,6 +28,7 @@ class DataViewsClient(BaseClient):
             "create_ml_configuration_from_datasets",
             "create_ml_configuration",
             "get_model_reports",
+            "get_relation_graph",
             "models",
             "search_template_client"
         ]
@@ -85,7 +86,7 @@ class DataViewsClient(BaseClient):
 
         return data_view_id
 
-    def update(self, id, configuration, name, description):
+    def update(self, id, configuration = None, name = None, description = None):
         """
         Updates an existing data view from the search template and ml template given
 
@@ -95,16 +96,15 @@ class DataViewsClient(BaseClient):
         :param description: Description for the data view
         """
 
-        data = {
-            "configuration":
-                configuration,
-            "name":
-                name,
-            "description":
-                description
-        }
+        data = {}
+        if configuration is not None:
+            data['configuration'] = configuration
+        if name is not None:
+            data['name'] = name
+        if description is not None:
+            data['description'] = description
 
-        failure_message = "Dataview creation failed"
+        failure_message = "Dataview update failed"
 
         self._patch_json(
             'v1/data_views/' + id, data, failure_message=failure_message)
@@ -167,6 +167,9 @@ class DataViewsClient(BaseClient):
         :param dataset_ids: Array of dataset identifiers to make search template from
         :return: An identifier used to request the status of the builder job (get_ml_configuration_status)
         """
+        if not isinstance(dataset_ids, list):
+            dataset_ids = [dataset_ids]
+
         available_columns = self.search_template_client.get_available_columns(dataset_ids)
 
         # Create a search template from dataset ids
@@ -216,6 +219,22 @@ class DataViewsClient(BaseClient):
         response = self._get('v1/data_views/{}/model_reports'.format(data_view_id)).json()
         return list(map(lambda report: ModelReport(report), response['data']))
 
+    def get_relation_graph(self, data_view_id):
+        """
+        Retrieves the relation graph of data views with ML configured, that can
+        be passed into the ``plot`` function of ``dagre_py.core`` for visualization.
+
+        A relation graph shows you how your inputs, outputs, and latent variables
+        are linked by Citrination's machine learning models.
+
+        :param data_view_id: the id of the view to retrieve relation graphs from
+        :type data_view_id: str
+        :return: A dict containing a list of nodes and edges
+        :rtype: dict
+        """
+        response = self._get('v1/data_views/{}/relation-graph'.format(data_view_id)).json()
+        return response['data']
+
     def __convert_response_to_configuration(self, result_blob, dataset_ids):
         """
         Utility function to turn the result object from the configuration builder endpoint into something that
